@@ -1,10 +1,12 @@
 # Trains and Updates Ultralytics HUB Models
 
-from . import AUTH
+from .auth import Auth
 from .config import BY_PASS_LOGIN
 from .trainer import Trainer
 from .yolov5_wrapper import verify_install
 
+AUTH = Auth()
+
 
 def setup_yolo() -> None:
     """Checks if yolov5 exists and if not clones it"""
